@@ -6,7 +6,7 @@ symlinkToUpstreamTarball=$3
 
 newdir=$(echo $symlinkToUpstreamTarball | sed -e 's%^\.\./%%' -e 's/.orig.tar.gz//' -e 's/_/-/')
 symlinkToUpstreamTarball=$(echo $symlinkToUpstreamTarball | sed -e 's%^\.\./%%')
-newdir=${newdir}~dfsg1
+newdir=${newdir}+dfsg1
 
 echo "convert geophar-$version to $newdir"
 wd=$(pwd)
@@ -34,11 +34,13 @@ cd $wd1
 echo "Those files were removed to comply with DFSG:" > $newdir/README.dfsg.txt
 echo $removedFiles >> $newdir/README.dfsg.txt
 
-archive=geophar_$version~dfsg1.orig.tar.xz
+archive=geophar_$version+dfsg1.orig.tar.xz
 
 tar cJf $archive $newdir
 
-echo created $archive and $newdir
+rm -rf $newdir
+
+echo created $archive
 
 rm $(readlink $symlinkToUpstreamTarball)
 rm $symlinkToUpstreamTarball
